Welcome to Places's documentation!
==================================

**places** is a django app (using geodjango) that allow you to manage geo-localized places.

Contents:

.. toctree::
   :maxdepth: 2

   installation
   views
   managers



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

